@@ -62,7 +62,7 @@ use Catmandu::Util qw(xml_escape is_different :array :is);
 use List::Util;
 use Moo;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 with 'Catmandu::Exporter', 'Catmandu::Exporter::MARC::Base';
 
@@ -101,6 +101,9 @@ sub add {
         next if $#data == -1;
 
         # Joins are faster than perl string concatenation
+        if (@data < 2) {
+            $self->log->warn("$tag doesn't have any data");
+        }
         if (index($tag,'LDR') == 0) {
             my $ldr = $data[1];
             $ldr =~ s/ /^/og;
